import { useQuery } from "@tanstack/react-query";
import { TransactionsByStudentAPI } from "../../API/API";
import styles, { colors } from "../../../styles";
import CircularProgress from "@mui/material/CircularProgress/CircularProgress";
import React, { useState } from "react";
import TransactionEntry from "../../TransactionEntry/TransactionEntry";
import TransactionFilterMenu from "../../TransactionFilterMenu/TransactionFilterMenu";
import { useNavigate } from "react-router-dom";

export default function StudentTransactionListView() {
  const navigate = useNavigate();
  const transactions = useQuery({
    queryKey: ["transactions_student"],
    queryFn: TransactionsByStudentAPI,
  });
  const [filter, setFilter] = useState("");
  if (transactions.isLoading) {
    return (
      <div
        style={{
          ...styles.flex_column,
          ...{
            alignItems: "center",
            justifyContent: "center",
            paddingTop: "64px",
          },
        }}
      >
        <CircularProgress style={{ height: "128px", width: "128px" }} />
        <p
          style={{
            ...styles.text_dark,
            ...styles.text_L,
          }}
        >
          Loading
        </p>
      </div>
    );
  }
  return (
    <div style={{ width: "100%" }}>
      <div style={{
        marginTop: "60px",
        width: "85%",
        marginInline: "6.5%"
       }}>
        <TransactionFilterMenu filter={filter} setFilter={setFilter} />
        <div style={{ marginTop: "16px" }} />
        <div
          style={{
            ...styles.flex_column,
            ...{ height: "60vh", overflowY: "scroll" },
          
          }}
        >
          {transactions.data ? (
            transactions.data
              .filter((transaction) =>
                filter !== "" ? transaction.transaction_status == filter : true
              )
              .map((transaction) => (
                <React.Fragment key={transaction.id}>
                  <TransactionEntry
                    onClick={() => {
                      navigate(`/view/transaction/${transaction.id}`, {
                        replace: true,
                        state: { id: transaction.id },
                      });
                    }}
                    transaction={transaction}
                  />
                  <button
                    style={{
                      borderTop: "2px solid rgba(160, 160, 160, 0.20)",
                      padding: "7px",
                      margin: "0px",
                      backgroundColor: colors.header_color,
                      width: 550,
                      alignSelf: "center",
                      borderRadius: "0px 0px 7px 7px",
                      
                    }}
                    onClick={() => {
                      navigate(`/view/transaction/${transaction.id}`, {
                        replace: true,
                        state: { id: transaction.id },
                      });
                    }}
                  >
                    <p
                      style={{
                        ...styles.text_gray,
                        ...styles.text_S,
                        padding: "0px",
                        margin: "0px",
                      }}
                    >
                      TAP TO VIEW
                    </p>
                  </button>
                </React.Fragment>
              ))
          ) : (
            <></>
          )}
        </div>
        
        
      </div>
    </div>
  );
}
